@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: mime-mail
 version: 0.4.11
-id: mime-mail-0.4.11-363f204ae632de52ba204fa0d2f16891
-key: mimem_8uaMEdoB8sbFJrrM08Zktu
+id: mime-mail-0.4.11-d9015aaaa236b99cae24cbb7fe985a3e
+key: mimem_GfwvuUO1sCuAzWhs10QE4S
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 homepage: http://github.com/snoyberg/mime-mail
@@ -19,11 +19,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/mime-mail-0.4.11
 library-dirs: /usr/lib/ghc-7.10.3/site-local/mime-mail-0.4.11
 data-dir: /usr/share/arm-linux-ghc-7.10.3/mime-mail-0.4.11
-hs-libraries: HSmime-mail-0.4.11-8uaMEdoB8sbFJrrM08Zktu
+hs-libraries: HSmime-mail-0.4.11-GfwvuUO1sCuAzWhs10QE4S
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
-    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
+    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
